@@ -83,10 +83,20 @@ class analyticsDb extends BaseDb
 	 */
 	function getOldAccessLog(&$row)
 	{
-		$queryStr  = 'SELECT * FROM _access_log ';
+/*		$queryStr  = 'SELECT * FROM _access_log ';
 		$queryStr .=   'ORDER BY al_serial';
 		$ret = $this->selectRecord($queryStr, array(), $row);
 		return $ret;
+		*/
+		$serial = 0;
+		$queryStr  = 'SELECT min(al_serial) as m FROM _access_log ';
+		$ret = $this->selectRecord($queryStr, array(), $row);
+		if ($ret) $serial = $row['m'];
+		
+		$queryStr  = 'SELECT * FROM _access_log ';
+		$queryStr .=   'WHERE al_serial = ?';
+		$ret = $this->selectRecord($queryStr, array($serial), $row);
+		return $ret;
 	}
 	/**
 	 * 時間単位で一日分の集計処理を行う
