@@ -545,17 +545,29 @@ class DesignManager extends Core
 	/**
 	 * 管理画面用パンくずリストを作成
 	 *
-	 * @param array $def				パンくずリストの定義
-	 * @return string 					パンくずリストのHTML
+	 * @param array $def		パンくずリストの定義
+	 * @param array $help		ヘルプ(title,bodyの連想配列)
+	 * @return string 			パンくずリストのHTML
 	 */
-	function createAdminBreadcrumb($def)
+	function createAdminBreadcrumb($def, $help = array())
 	{
-		$destHtml = '<ol class="breadcrumb">';
+		$destHtml = '<div class="m3breadcrumbbar">';
+		$destHtml .= '<ol class="breadcrumb">';
 		for ($i = 0; $i < count($def); $i++){
 			$name = $def[$i];
 			$destHtml .= '<li>' . convertToHtmlEntity($name) . '</li>';
 		}
 		$destHtml .= '</ol>';
+		
+		// ヘルプが設定されている場合は追加
+		if (!empty($help)){
+			$title = $help['title'];
+			if (!empty($title)){
+				$helpText = $this->gInstance->getHelpManager()->createHelpText($title, $help['body']);
+				$destHtml .= '<span ' . $helpText . '><i class="glyphicon glyphicon-question-sign text-warning"></i></span>';
+			}
+		}
+		$destHtml .= '</div>';
 		return $destHtml;
 	}
 	/**
