@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_image2WidgetContainer.php 2266 2009-08-28 08:25:59Z fishbone $
+ * @version    SVN: $Id: admin_image2WidgetContainer.php 2268 2009-08-31 03:29:18Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -343,8 +343,6 @@ class admin_image2WidgetContainer extends BaseAdminWidgetContainer
 		$this->tmpl->addVar("_widget", "image", $destImg);
 		
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);// 選択中のシリアル番号、IDを設定
-		$this->tmpl->addVar("_widget", "widget_url", $this->gEnv->getCurrentWidgetRootUrl());	// ウィジェットのルートディレクトリ
-		$this->tmpl->addVar("_widget", "root_url", $this->gEnv->getRootUrl());
 		
 		// ボタンの表示制御
 		if (empty($this->serialNo)){		// 新規追加項目を選択しているとき
@@ -503,7 +501,7 @@ class admin_image2WidgetContainer extends BaseAdminWidgetContainer
 				'def_count' => $defCount,							// 使用数
 				'width' => $imgWidth,					// 画像幅
 				'height' => $imgHeight,					// 画像高さ
-				'url' => $url					// URL
+				'url' => $this->getUrl($url)					// URL
 			);
 			$this->tmpl->addVars('itemlist', $row);
 			$this->tmpl->parseTemplate('itemlist', 'a');
